import { useState } from "react";
import InviteCodes from "./features/invites/InviteCodes";
import UserList from "./features/users/UserList";

const TABS = {
  invites: {
    component: InviteCodes,
    label: "Invite Codes",
  },
  users: {
    component: UserList,
    label: "User List",
  },
} as const;

type TabKey = keyof typeof TABS;

export default function TabView() {
  const [activeTab, setActiveTab] = useState<TabKey>("invites");
  const ActiveComponent = TABS[activeTab].component;

  return (
    <div className="w-full container mx-auto max-w-3xl p-4">
      <div className="card bg-base-100 shadow-xl">
        <div className="card-body">
          <div className="tabs tabs-boxed">
            {Object.entries(TABS).map(([key, { label }]) => (
              <button
                key={key}
                className={`tab ${activeTab === key ? "tab-active" : ""}`}
                onClick={() => setActiveTab(key as TabKey)}
              >
                {label}
              </button>
            ))}
          </div>
          <div className="mt-4">
            <ActiveComponent />
          </div>
        </div>
      </div>
    </div>
  );
}
